@@ -18,6 +18,7 @@ import (
 	"net/url"
 	"os"
 	"reflect"
+	"slices"
 	"sort"
 	"strings"
 	"sync"
@@ -206,21 +207,21 @@ func TestListContainers(t *testing.T) {
 			Ports:   container.NetworkSettings.PortMappingAPI(),
 			Names:   []string{"/" + container.Name},
 			State:   container.State.StateString(),
+			Labels:  map[string]string{"key": fmt.Sprintf("val-%d", i)},
 		}
 	}
-	sort.Slice(expected, func(i, j int) bool {
-		return expected[i].ID < expected[j].ID
-	})
+	sortFn := func(left, right docker.APIContainers) int {
+		return strings.Compare(left.ID, right.ID)
+	}
+	slices.SortFunc(expected, sortFn)
 	var got []docker.APIContainers
 	err := json.NewDecoder(recorder.Body).Decode(&got)
 	if err != nil {
 		t.Fatal(err)
 	}
-	sort.Slice(got, func(i, j int) bool {
-		return got[i].ID < got[j].ID
-	})
+	slices.SortFunc(got, sortFn)
 	if !reflect.DeepEqual(got, expected) {
-		t.Errorf("ListContainers. Want %#v. Got %#v.", expected, got)
+		t.Errorf("ListContainers.\nWant %#v.\nGot  %#v.", expected, got)
 	}
 }
 
@@ -2757,7 +2758,7 @@ func TestInfoDocker(t *testing.T) {
 	if recorder.Code != http.StatusOK {
 		t.Fatalf("InfoDocker: wrong status. Want %d. Got %d.", http.StatusOK, recorder.Code)
 	}
-	var infoData map[string]interface{}
+	var infoData map[string]any
 	err := json.Unmarshal(recorder.Body.Bytes(), &infoData)
 	if err != nil {
 		t.Fatal(err)
